@@ -502,6 +502,8 @@ cc_network_panel_get_devices (CcNetworkPanel *panel)
                                     -1);
                 if (NET_IS_DEVICE (object))
                         g_ptr_array_add (devices, object);
+                else
+                        g_object_unref (object);
         } while (gtk_tree_model_iter_next (model, &iter));
 
         return devices;
@@ -943,7 +945,6 @@ out:
 static void
 panel_add_proxy_device (CcNetworkPanel *panel)
 {
-        gchar *title;
         GtkListStore *liststore_devices;
         GtkTreeIter iter;
         NetProxy *proxy;
@@ -963,8 +964,7 @@ panel_add_proxy_device (CcNetworkPanel *panel)
         /* add proxy to device list */
         liststore_devices = GTK_LIST_STORE (gtk_builder_get_object (panel->priv->builder,
                                             "liststore_devices"));
-        title = g_strdup_printf ("%s", _("Network proxy"));
-        net_object_set_title (NET_OBJECT (proxy), title);
+        net_object_set_title (NET_OBJECT (proxy), _("Network proxy"));
         gtk_list_store_append (liststore_devices, &iter);
         gtk_list_store_set (liststore_devices,
                             &iter,
@@ -972,7 +972,6 @@ panel_add_proxy_device (CcNetworkPanel *panel)
                             PANEL_DEVICES_COLUMN_SORT, "9",
                             PANEL_DEVICES_COLUMN_OBJECT, proxy,
                             -1);
-        g_free (title);
         g_object_unref (proxy);
 }
 
@@ -1153,6 +1152,7 @@ panel_add_vpn_device (CcNetworkPanel *panel, NMConnection *connection)
                             PANEL_DEVICES_COLUMN_OBJECT, net_vpn,
                             -1);
         g_free (title);
+        g_object_unref (net_vpn);
 }
 
 static void
@@ -1218,6 +1218,7 @@ panel_add_virtual_device (CcNetworkPanel *panel, NMConnection *connection)
                             PANEL_DEVICES_COLUMN_OBJECT, net_virt,
                             -1);
         g_free (title);
+        g_object_unref (net_virt);
 }
 
 static void
