@@ -95,9 +95,9 @@ locale_info_free (gpointer data)
   g_free (info->name);
   g_free (info->unaccented_name);
   g_free (info->untranslated_name);
-  g_object_unref (info->default_input_source_row);
-  g_object_unref (info->locale_row);
-  g_object_unref (info->back_row);
+  g_clear_object (&info->default_input_source_row);
+  g_clear_object (&info->locale_row);
+  g_clear_object (&info->back_row);
   g_hash_table_destroy (info->layout_rows_by_id);
   g_hash_table_destroy (info->engine_rows_by_id);
   g_free (info);
@@ -395,6 +395,7 @@ show_input_sources_for_locale (GtkWidget   *chooser,
   gtk_list_box_invalidate_filter (GTK_LIST_BOX (priv->list));
   gtk_list_box_set_selection_mode (GTK_LIST_BOX (priv->list), GTK_SELECTION_SINGLE);
   gtk_list_box_set_activate_on_single_click (GTK_LIST_BOX (priv->list), FALSE);
+  gtk_list_box_unselect_all (GTK_LIST_BOX (priv->list));
 
   if (gtk_widget_is_visible (priv->filter_entry) &&
       !gtk_widget_is_focus (priv->filter_entry))
@@ -1139,7 +1140,6 @@ cc_input_chooser_new (GtkWindow    *main_window,
   chooser = WID ("input-dialog");
   priv = g_new0 (CcInputChooserPrivate, 1);
   g_object_set_data_full (G_OBJECT (chooser), "private", priv, cc_input_chooser_private_free);
-  g_object_set_data_full (G_OBJECT (chooser), "builder", builder, g_object_unref);
 
   priv->is_login = is_login;
   priv->xkb_info = xkb_info;
@@ -1179,6 +1179,8 @@ cc_input_chooser_new (GtkWindow    *main_window,
 
   gtk_window_set_transient_for (GTK_WINDOW (chooser), main_window);
 
+  g_object_unref (builder);
+
   return chooser;
 }
 
@@ -1226,3 +1228,9 @@ cc_input_chooser_get_selected (GtkWidget  *chooser,
 
   return TRUE;
 }
+
+void
+cc_input_chooser_reset (GtkWidget *chooser)
+{
+  show_locale_rows (chooser);
+}
