@@ -30,9 +30,11 @@ G_BEGIN_DECLS
 
 void     cc_panel_loader_fill_model     (CcShellModel  *model);
 GList   *cc_panel_loader_get_panels     (void);
+void     cc_panel_loader_add_option_groups (GOptionContext  *context,
+                                            GVariantBuilder *builder);
 CcPanel *cc_panel_loader_load_by_name   (CcShell       *shell,
                                          const char    *name,
-                                         const char   **argv);
+                                         GVariant      *parameters);
 
 G_END_DECLS
 
